#include <DHT.h>
#include <SPI.h>
#include <TemperaturePacket.h>
#include <nRF24L01.h>
#include <RF24.h>
#include <RF24_config.h>
#include <stdio.h>
#include<stdlib.h>

const int DHTPIN_A = 2;
const int DHTPIN_B = 3;

const int RF24_CE = 9;
const int RF24_CSN = 10;

const int PACKET_SIZE = 255;

DHT dht_a(DHTPIN_A, DHT22);
DHT dht_b(DHTPIN_B, DHT22);
RF24 radio(RF24_CE, RF24_CSN);

const uint64_t WRITE_PIPE = 0x0000000002LL;

void setup()
{
  Serial.begin(9600);
  dht_a.begin();
  dht_b.begin();
  radio.begin();
  radio.setRetries(15,15);
  radio.openWritingPipe(WRITE_PIPE);
}

void loop()
{
  TemperaturePacket packet = readDHT(dht_a, 'A');
  //sendPacket(packet);
  packet = readDHT(dht_b, 'B');
  //sendPacket(packet);
  
  delay(2000);
}

TemperaturePacket readDHT(DHT& dht, char probe)
{
  float dhtTemperature = dht.readTemperature();
  float dhtHumidity = dht.readHumidity(); 
  
  Serial.print("Probe: ");
  Serial.print(probe);
  Serial.print(" Temp (C): ");
  Serial.print(dhtTemperature);
  Serial.print(" Humidity: ");
  Serial.println(dhtHumidity);
  
  TemperaturePacket packet = TemperaturePacket(probe, dhtTemperature, dhtHumidity);
  return packet;
}

void sendPacket(TemperaturePacket packet)
{
  sendMetric("Gauge", "Temperature.Test", packet.Temperature);
  sendMetric("Gauge", "Humidity.Test", packet.Humidity);
}

void formatMetric(char* buffer, int bufferSize, char* metricType, char* metricName, float value)
{
  char numberBuffer[32];
  dtostrf(value, 0, 5, numberBuffer);
  snprintf(buffer, bufferSize, "%s,%s,%s\r\n", metricType, metricName, numberBuffer);
}

void sendMetric(char* metricType, char* metricName, float value)
{
   char metricString[PACKET_SIZE];
   memset(metricString,0,sizeof(metricString));
   formatMetric(metricString, PACKET_SIZE, metricType, metricName, value);
   
   Serial.print(metricString);
   Serial.println(strlen(metricString));
  
   bool ok = radio.write( &metricString, PACKET_SIZE );
   Serial.print("Send Status: ");
   Serial.println(ok);
}


